==> google-cloud-asset-3.8.1.tar.gz: google-cloud-asset-3.8.1/google/cloud/asset_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .asset_service import (
    AnalyzeIamPolicyLongrunningMetadata,
    AnalyzeIamPolicyLongrunningRequest,
    AnalyzeIamPolicyLongrunningResponse,
    AnalyzeIamPolicyRequest,
    AnalyzeIamPolicyResponse,
    AnalyzeMoveRequest,
    AnalyzeMoveResponse,
    BatchGetAssetsHistoryRequest,
    BatchGetAssetsHistoryResponse,
    BigQueryDestination,
    CreateFeedRequest,
    DeleteFeedRequest,
    ExportAssetsRequest,
    ExportAssetsResponse,
    Feed,
    FeedOutputConfig,
    GcsDestination,
    GcsOutputResult,
    GetFeedRequest,
    IamPolicyAnalysisOutputConfig,
    IamPolicyAnalysisQuery,
    ListAssetsRequest,
    ListAssetsResponse,
    ListFeedsRequest,
    ListFeedsResponse,
    MoveAnalysis,
    MoveAnalysisResult,
    MoveImpact,
    OutputConfig,
    OutputResult,
    PartitionSpec,
    PubsubDestination,
    SearchAllIamPoliciesRequest,
    SearchAllIamPoliciesResponse,
    SearchAllResourcesRequest,
    SearchAllResourcesResponse,
    UpdateFeedRequest,
    ContentType,
)
from .assets import (
    Asset,
    AttachedResource,
    ConditionEvaluation,
    IamPolicyAnalysisResult,
    IamPolicyAnalysisState,
    IamPolicySearchResult,
    RelatedAsset,
    RelatedAssets,
    RelatedResource,
    RelatedResources,
    RelationshipAttributes,
    Resource,
    ResourceSearchResult,
    TemporalAsset,
    TimeWindow,
    VersionedResource,
)

__all__ = (
    "AnalyzeIamPolicyLongrunningMetadata",
    "AnalyzeIamPolicyLongrunningRequest",
    "AnalyzeIamPolicyLongrunningResponse",
    "AnalyzeIamPolicyRequest",
    "AnalyzeIamPolicyResponse",
    "AnalyzeMoveRequest",
    "AnalyzeMoveResponse",
    "BatchGetAssetsHistoryRequest",
    "BatchGetAssetsHistoryResponse",
    "BigQueryDestination",
    "CreateFeedRequest",
    "DeleteFeedRequest",
    "ExportAssetsRequest",
    "ExportAssetsResponse",
    "Feed",
    "FeedOutputConfig",
    "GcsDestination",
    "GcsOutputResult",
    "GetFeedRequest",
    "IamPolicyAnalysisOutputConfig",
    "IamPolicyAnalysisQuery",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListFeedsRequest",
    "ListFeedsResponse",
    "MoveAnalysis",
    "MoveAnalysisResult",
    "MoveImpact",
    "OutputConfig",
    "OutputResult",
    "PartitionSpec",
    "PubsubDestination",
    "SearchAllIamPoliciesRequest",
    "SearchAllIamPoliciesResponse",
    "SearchAllResourcesRequest",
    "SearchAllResourcesResponse",
    "UpdateFeedRequest",
    "ContentType",
    "Asset",
    "AttachedResource",
    "ConditionEvaluation",
    "IamPolicyAnalysisResult",
    "IamPolicyAnalysisState",
    "IamPolicySearchResult",
    "RelatedAsset",
    "RelatedAssets",
    "RelatedResource",
    "RelatedResources",
    "RelationshipAttributes",
    "Resource",
    "ResourceSearchResult",
    "TemporalAsset",
    "TimeWindow",
    "VersionedResource",
)

==> google-cloud-asset-3.11.0.tar.gz: google-cloud-asset-3.11.0/google/cloud/asset_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .asset_service import (
    AnalyzeIamPolicyLongrunningMetadata,
    AnalyzeIamPolicyLongrunningRequest,
    AnalyzeIamPolicyLongrunningResponse,
    AnalyzeIamPolicyRequest,
    AnalyzeIamPolicyResponse,
    AnalyzeMoveRequest,
    AnalyzeMoveResponse,
    BatchGetAssetsHistoryRequest,
    BatchGetAssetsHistoryResponse,
    BatchGetEffectiveIamPoliciesRequest,
    BatchGetEffectiveIamPoliciesResponse,
    BigQueryDestination,
    CreateFeedRequest,
    CreateSavedQueryRequest,
    DeleteFeedRequest,
    DeleteSavedQueryRequest,
    ExportAssetsRequest,
    ExportAssetsResponse,
    Feed,
    FeedOutputConfig,
    GcsDestination,
    GcsOutputResult,
    GetFeedRequest,
    GetSavedQueryRequest,
    IamPolicyAnalysisOutputConfig,
    IamPolicyAnalysisQuery,
    ListAssetsRequest,
    ListAssetsResponse,
    ListFeedsRequest,
    ListFeedsResponse,
    ListSavedQueriesRequest,
    ListSavedQueriesResponse,
    MoveAnalysis,
    MoveAnalysisResult,
    MoveImpact,
    OutputConfig,
    OutputResult,
    PartitionSpec,
    PubsubDestination,
    SavedQuery,
    SearchAllIamPoliciesRequest,
    SearchAllIamPoliciesResponse,
    SearchAllResourcesRequest,
    SearchAllResourcesResponse,
    UpdateFeedRequest,
    UpdateSavedQueryRequest,
    ContentType,
)
from .assets import (
    Asset,
    AttachedResource,
    ConditionEvaluation,
    IamPolicyAnalysisResult,
    IamPolicyAnalysisState,
    IamPolicySearchResult,
    RelatedAsset,
    RelatedAssets,
    RelatedResource,
    RelatedResources,
    RelationshipAttributes,
    Resource,
    ResourceSearchResult,
    TemporalAsset,
    TimeWindow,
    VersionedResource,
)

__all__ = (
    "AnalyzeIamPolicyLongrunningMetadata",
    "AnalyzeIamPolicyLongrunningRequest",
    "AnalyzeIamPolicyLongrunningResponse",
    "AnalyzeIamPolicyRequest",
    "AnalyzeIamPolicyResponse",
    "AnalyzeMoveRequest",
    "AnalyzeMoveResponse",
    "BatchGetAssetsHistoryRequest",
    "BatchGetAssetsHistoryResponse",
    "BatchGetEffectiveIamPoliciesRequest",
    "BatchGetEffectiveIamPoliciesResponse",
    "BigQueryDestination",
    "CreateFeedRequest",
    "CreateSavedQueryRequest",
    "DeleteFeedRequest",
    "DeleteSavedQueryRequest",
    "ExportAssetsRequest",
    "ExportAssetsResponse",
    "Feed",
    "FeedOutputConfig",
    "GcsDestination",
    "GcsOutputResult",
    "GetFeedRequest",
    "GetSavedQueryRequest",
    "IamPolicyAnalysisOutputConfig",
    "IamPolicyAnalysisQuery",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListFeedsRequest",
    "ListFeedsResponse",
    "ListSavedQueriesRequest",
    "ListSavedQueriesResponse",
    "MoveAnalysis",
    "MoveAnalysisResult",
    "MoveImpact",
    "OutputConfig",
    "OutputResult",
    "PartitionSpec",
    "PubsubDestination",
    "SavedQuery",
    "SearchAllIamPoliciesRequest",
    "SearchAllIamPoliciesResponse",
    "SearchAllResourcesRequest",
    "SearchAllResourcesResponse",
    "UpdateFeedRequest",
    "UpdateSavedQueryRequest",
    "ContentType",
    "Asset",
    "AttachedResource",
    "ConditionEvaluation",
    "IamPolicyAnalysisResult",
    "IamPolicyAnalysisState",
    "IamPolicySearchResult",
    "RelatedAsset",
    "RelatedAssets",
    "RelatedResource",
    "RelatedResources",
    "RelationshipAttributes",
    "Resource",
    "ResourceSearchResult",
    "TemporalAsset",
    "TimeWindow",
    "VersionedResource",
)
